@@ -1,12 +1,11 @@
 
-__version__ = "0.2.1"
+__version__ = "0.3.2"
 
 
 
 
 
 from ._function import napari_experimental_provide_function
-from ._dock_widget import napari_experimental_provide_dock_widget
 
 from napari.types import ImageData, LabelsData
 import napari
@@ -48,7 +47,7 @@ def time_slicer(function: Callable) -> Callable:
         start_time = time.time()
 
         if viewer is None:
-            warnings.warn("No viewer provided, cannot read current time point.")
+            print("No viewer provided, cannot read current time point.")
         else:
             workflow_manager = WorkflowManager.install(viewer)
 
